@@ -15,7 +15,8 @@ import h5py
 from . import class_HDF5
 import time
 import pdb
-import mat73
+#import mat73
+import hdf5storage
 #import time
 
 d=dict() #this dictionnary containes the names of the index files loaded in search_htm_ind, and allowes us to avoid loading twice the same index file, which can be time consuming e.g. in a loop
@@ -120,9 +121,9 @@ def cone_search(CatName,RA,Dec,Radius,catalogs_dir='./data',RadiusUnits='arcsec'
             test = sio.loadmat(root_to_data+CatDir+'/'+ColCelFile)
             #test = mat73.loadmat(root_to_data + CatDir + '/' + ColCelFile)
         except:
-            print('sio.loadmat did not work for opening {0}, I am trying mat73.loadmat'.format(root_to_data+CatDir+'/'+ColCelFile))
+            print('sio.loadmat did not work for opening {0}, I am trying hdf5storage.loadmat'.format(root_to_data+CatDir+'/'+ColCelFile))
             #test = sio.loadmat(root_to_data + CatDir + '/' + ColCelFile)
-            test= mat73.loadmat(root_to_data+CatDir+'/'+ColCelFile)
+            test= hdf5storage.loadmat(root_to_data+CatDir+'/'+ColCelFile)
         #print(test1)
         #print(test2)
         #pdb.set_trace()
